# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-B-Keywords
Version:	1.26
Release:	1.%{__distinit}%{__distvers}
Summary:	Lists of reserved barewords and symbol names
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/B-Keywords
Source0:	https://cpan.metacpan.org/modules/by-module/B/B-Keywords-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl-devel
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(warnings)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.0
# Maintainer Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(List::MoreUtils)
BuildRequires:	perl(Perl::MinimumVersion) >= 1.20
BuildRequires:	perl(Test::CPAN::Meta) >= 0.12
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion) >= 0.008
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Text::CSV_XS)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
B::Keywords supplies several arrays of exportable keywords: @Scalars, @Arrays,
@Hashes, @Filehandles, @Symbols, @Functions, @Barewords, @TieIOMethods,
@UNIVERSALMethods and @ExporterSymbols.

The @Symbols array includes the contents of each of @Scalars, @Arrays, @Hashes,
@Functions and @Filehandles.

Similarly, @Barewords adds a few non-function keywords and operators to the
@Functions array.

%prep
%setup -q -n B-Keywords-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test %{!?perl_bootstrap:IS_MAINTAINER=1 AUTHOR_TESTING=1}

%files
%license LICENSE
%doc Changes
%{perl_vendorlib}/B/
%{_mandir}/man3/B::Keywords.3*

%changelog
* Tue Jun 20 2023 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Add Corinna keywords, new with Perl 5.38.0 (GH#8)
  - ADJUST class field method
  - Updated README
- Use SPDX-format license tag

* Wed Feb 23 2022 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Fix for broken <archlibexp>/CORE/keywords.h test on system macOS (GH#5)
  - 'finally' added with 5.35.8 (CPAN RT#141406)

* Sun Oct 31 2021 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Relax bogus blead test failures
  - Add reverse test: if @Barewords are covered on keywords.h
  - Move some @Barewords not in keywords.h to @BarewordsExtra
  - Add %%main, %%CORE, %%CORE::GLOBAL:: to @Hashes
  - Fixed versions for EQ, CORE, state, break, given, when, default, UNITCHECK
- Fix dist tags for Alma and Rocky Linux

* Mon Feb 22 2021 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - try/catch was added with 5.33.7
- Use %%license unconditionally

* Tue Dec 17 2019 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
   - isa was added with 5.31.7
   - Improved t/z_kwalitee.t

* Fri Feb 15 2019 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - extern was added with 5.29.0c

* Thu Aug 23 2018 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - our was added with 5.005_61
- Switch upstream from search.cpan.org to metacpan.org

* Tue Jan 30 2018 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
  - Added 5.27.8 changes: no whereis/-so

* Sun Dec 31 2017 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - Added 5.27.7 changes (CPAN RT#123948)
  - Added cperl class keywords
  - Added keywords per version back to 5.004
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally
  - Run maintainer tests unconditionally

* Fri Aug  5 2016 Paul Howarth <paul@city-fan.org> - 1.15-4
- BR: perl-generators where available
- Simplify find command using -delete

* Wed Nov 11 2015 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Fixed $OUTPUT_AUTOFLUSH (CPAN RT#108572)
  - Made $* $MULTILINE_MATCHING version specific, deprecated with 5.8.1,
    removed with 5.10
- Explicitly require perl-devel, for CORE/keywords.h

* Wed Jul  1 2015 Paul Howarth <paul@city-fan.org> - 1.14-4
- Perl 5.22 re-rebuild of bootstrapped packages

* Tue Jun 16 2015 Paul Howarth <paul@city-fan.org> - 1.14-2
- Perl 5.22 bootstrap

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Removed err from Barewords (CPAN RT#102259)
- Run the maintainer tests if we're not bootstrapping and the required
  modules are available
- Expand %%description
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> 1.13-5
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4

* Tue Jul 16 2013 Paul Howarth <paul@city-fan.org> 1.13-2
- Perl 5.18 rebuild

* Sat Apr  6 2013 Paul Howarth <paul@city-fan.org> 1.13-1
- Update to 1.13
  - Removed diag before each big t/11keywords.t loop
  - Added lots of suggested keywords from CPAN RT#62382
  - Moved exp from @Barewords to @Functions
  - Added $^CHILD_ERROR_NATIVE $^GLOBAL_PHASE $^LAST_FH $^MATCH $^PREMATCH
    $^POSTMATCH $^UTF8CACHE $^WIN32_SLOPPY_STAT to @Scalars
  - Added English names for %%!, @F (perlrun) and @ARG for @_
  - Added %%+ %%- and $LAST_SUBMATCH_RESULT
- BR: perl(Test::Pod)

* Thu Jun 14 2012 Paul Howarth <paul@city-fan.org> 1.12-2
- BR: perl(Exporter), perl(lib), perl(File::Spec) and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Feb 10 2012 Paul Howarth <paul@city-fan.org> 1.12-1
- Update to 1.12
  - Add new keyword fc (Unicode casefolding) for 5.16
  - Added diag before each big t/11keywords.t loop
- This release by RURBAN -> update source URL

* Wed Jan 11 2012 Paul Howarth <paul@city-fan.org> 1.11-1
- Update to 1.11
  - Add new keywords for 5.16: __SUB__ and evalbytes

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> 1.10-3
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> 1.10-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands

* Sun Sep  5 2010 Paul Howarth <paul@city-fan.org> 1.10-1
- Update to 1.10 (fix typo in SYNOPSIS)
- This release by FLORA -> update source URL

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> 1.09-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> 1.09-5
- Fix dist tag for RHEL-6 Beta

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> 1.09-4
- Import from Fedora

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.09-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Mar 28 2009 Chris Weyl <cweyl@alumni.drew.edu> 1.09-2
- BR Test -> Test::More

* Sat Mar 28 2009 Chris Weyl <cweyl@alumni.drew.edu> 1.09-1
- Update to 1.09

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.08-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat May 31 2008 Chris Weyl <cweyl@alumni.drew.edu> 1.08-2
- Update buildrequires

* Sat Mar 15 2008 Chris Weyl <cweyl@alumni.drew.edu> 1.08-1
- Update to 1.08

* Thu Feb 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.06-4
- Rebuild normally, second pass

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.06-3
- Rebuild for perl 5.10 (again), disable tests for first pass

* Mon Jan 14 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.06-2
- Rebuild normally, second pass

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.06-1.1
- Rebuild for new perl
- Disable Test-Pod-Coverage, tests for first pass

* Thu Feb 15 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.06-1
- Update to 1.06

* Sat Jan 20 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.05-1
- First build
